(function(PLUGIN_ID) {
  const config       = kintone.plugin.app.getConfig(PLUGIN_ID);
  const urlUpload    = 'https://api.openai.com/v1/files';
  const urlChat      = 'https://api.openai.com/v1/responses';
  const replyFieldCode = config.replyField;

  kintone.events.on('app.record.detail.show', function(event) {
    const spaceElement = kintone.app.record.getSpaceElement(config.spaceId);

    const button = new Kuc.Button({
      text: 'PDFをAIに送信',
      type: 'submit',
      id: 'ai-button',
      className: 'options-class',
      visible: true
    });

    const notification = new Kuc.Notification({
      text: '処理中です。お待ちください...',
      duration: -1
    });

    spaceElement.appendChild(button);

    button.addEventListener('click', async () => {
      const record  = kintone.app.record.get().record;
      const pdfFile = record[config.pdfFileField]?.value?.[0];

      if (!pdfFile || !pdfFile.fileKey) {
        alert('PDFファイルが添付されていません。');
        return;
      }

      notification.open();

      try {
        // --- PDF ファイル取得 ---
        const fileUrl = `/k/v1/file.json?fileKey=${encodeURIComponent(pdfFile.fileKey)}`;
        const blobRes = await fetch(fileUrl, {
          method: 'GET',
          headers: { 'X-Requested-With': 'XMLHttpRequest' }
        });
        if (!blobRes.ok) throw new Error(`ファイル取得に失敗しました（${blobRes.status}）`);
        const fileBlob = await blobRes.blob();

        // --- OpenAI にアップロード ---
        const uploadForm = new FormData();
        uploadForm.append('file', new File([fileBlob], pdfFile.name));
        uploadForm.append('purpose', 'user_data');

        const uploadRes  = await fetch(urlUpload, {
          method: 'POST',
          headers: { 'Authorization': `Bearer ${config.apikey}` },
          body: uploadForm
        });
        const uploadJson = await uploadRes.json();
        const fileId     = uploadJson.id;
        if (!fileId) throw new Error('ファイルアップロードに失敗しました');

        // --- プロンプト構築 ---
        const promptText = config.role;
        const payload = {
          model: config.model,
          input: [
            {
              role: 'system',
              content: [
                {
                  type: 'input_text',
                  text: 'あなたはPDFドキュメント解析の専門家AIです。・画像や表、図版を含むPDF全体を理解し、文字情報とビジュアル情報を組み合わせて処理します。・ユーザーからの指示（要約、抽出、分類など）に従い、必要な情報のみを過不足なく返してください。'
                }
              ]
            },
            {
              role: 'user',
              content: [
                { type: 'input_file', file_id: fileId },
                { type: 'input_text', text: promptText }
              ]
            }
          ]
        };

        // --- ChatGPT 呼び出し via proxy ---
        await new Promise((resolve, reject) => {
          kintone.plugin.app.proxy(
            PLUGIN_ID,
            urlChat,
            'POST',
            {
              'Authorization': `Bearer ${config.apikey}`,
              'Content-Type': 'application/json'
            },
            JSON.stringify(payload),
            (body, status) => {
              if (status !== 200) {
                return reject(new Error(`APIエラー: HTTP ${status}`));
              }
              const chatJson = JSON.parse(body);
              const aiText   = chatJson.output?.[0]?.content?.[0]?.text;
              if (!aiText || typeof aiText !== 'string') {
                return reject(new Error('AIからの回答を取得できませんでした'));
              }
              sessionStorage.setItem('aiGeneratedText', aiText);
              resolve();
            },
            (error) => {
              reject(new Error('Proxy呼び出しエラー: ' + (error.message || error)));
            }
          );
        });

        notification.close();

        // --- レコード編集画面へ遷移 ---
        const appId     = kintone.app.getId();
        const recordId  = kintone.app.record.getId();
        location.href   = `/k/${appId}/show#record=${recordId}&mode=edit`;

      } catch (e) {
        console.error('❌ エラー:', e);
        notification.text = 'エラーが発生しました: ' + (e.message || e);
        setTimeout(() => notification.close(), 5000);
      }
    });

    return event;
  });

  kintone.events.on(['app.record.edit.show', 'app.record.create.show'], function(event) {
    const aiGeneratedText = sessionStorage.getItem('aiGeneratedText');
    if (aiGeneratedText) {
      event.record[replyFieldCode].value = aiGeneratedText;
      sessionStorage.removeItem('aiGeneratedText');
    }
    return event;
  });

})(kintone.$PLUGIN_ID);